package com.me.common.ecs.event;

import java.lang.reflect.Method;

public class RegisteredListener {

    private final Listener listener;
    private final Method method;
    private final Class<? extends Event> eventType;
    private final EventHandler eh;

    public RegisteredListener(Listener listener, Method method, Class<? extends Event> eventType, EventHandler eh) {
        this.listener = listener;
        this.method = method;
        this.eventType = eventType;
        this.eh = eh;
    }

    public boolean isIgnoringCancelled() {
        return eh.ignoreCancelled();
    }

    public void execute(Event event) {
        if (!eventType.isAssignableFrom(event.getClass())) {
            return;
        }

        try {
            method.invoke(listener, event);
        } catch (Throwable e) {
            System.err.println("Could not call event " + event.toString() + ": " + e);
        }
    }

}
